@@ -36,6 +36,7 @@ from os.path import (
 from os.path import isfile as isfile_base
 from os.path import isdir as isdir_base
 
+from .events import before, after
 
 LOCAL_FILE = lambda *path: join(abspath(dirname(__file__)), *path)
 
@@ -288,21 +289,30 @@ class DocumentIndexer(object):
     def find_all_markdown_files(self):
         dirs = []
 
-        for md_node in self.node.grep(r'[.](md|markdown)$', re.I):
+        grep_result = self.node.grep(r'[.](md|markdown)$', re.I)
+        total_results = len(grep_result)
+        for position, md_node in enumerate(grep_result, start=1):
             folder = md_node.dir.path
             if md_node.dir != self.node.dir and folder not in dirs:
                 dirs.append(folder)
-                yield {
+                folder_info = {
                     'path': folder,
                     'relative_path': self.node.relative(folder) or './',
                     'type': 'tree',
                 }
+                after.folder_indexed.shout(
+                    folder_info, position, total_results, grep_result)
+                yield folder_info
 
-            yield {
+            file_info = {
                 'path': md_node.path,
                 'relative_path': self.node.relative(md_node.path),
                 'type': 'blob',
             }
+            after.file_indexed.shout(
+                folder_info, position, total_results, grep_result)
+
+            yield file_info
 
 
 class Generator(object):
@@ -317,6 +327,7 @@ class Generator(object):
         return self.regex.sub('.html', path)
 
     def relative_link_callback(self, original_link, current_document_info, destination_root):
+
         fixed_link, levels = self.get_levels(original_link)
 
         is_markdown = self.regex.search(original_link)
@@ -399,15 +410,21 @@ class Generator(object):
             relative_destiny = split(destiny)[0]
 
             if relative_destiny and not exists(relative_destiny):
+                before.folder_created.shout(relative_destiny)
                 os.makedirs(relative_destiny)
+                after.folder_created.shout(relative_destiny)
 
             with destination.open(destiny, 'w') as f:
-                f.write(item['html'].decode('utf-8'))
+                value = item['html'].decode('utf-8')
+                value = before.html_persisted.shout(destiny, value) or value
+                f.write(value)
+                after.html_persisted.shout(destiny, value)
 
             ret.append(destiny)
 
         missed_files = []
-        for src in self.files_to_copy:
+        total_files_to_copy = len(self.files_to_copy)
+        for position, src in enumerate(self.files_to_copy, start=1):
             src = relpath(src)
             in_theme = self.theme.node.find(src)
             in_local = self.project.node.find(src)
@@ -415,13 +432,16 @@ class Generator(object):
             if in_local:
                 found = in_local
                 found_base = self.project.node.dir
+                after.project_file_found.shout(found, found_base)
 
             elif in_theme:
                 found = in_theme
                 found_base = self.theme.node.dir
+                after.theme_file_found.shout(found, found_base)
 
             else:
                 missed_files.append(src)
+                after.missed_file.shout(src)
                 continue
 
             source = found.path
@@ -432,13 +452,19 @@ class Generator(object):
             destiny_folder = dirname(destiny)
 
             if not exists(destiny_folder):
+                before.folder_created.shout(relative_destiny)
                 os.makedirs(destiny_folder)
+                after.folder_created.shout(relative_destiny)
 
             already_exists = exists(destiny)
             should_update = already_exists and Node(destiny).could_be_updated_by(Node(source))
 
             if not already_exists or should_update:
+                before.file_copied.shout(
+                    source, destiny, position, total_files_to_copy)
                 shutil.copy2(source, destiny)
+                after.file_copied.shout(
+                    source, destiny, position, total_files_to_copy)
 
         cloner = AssetsCloner(self.theme.index['static_path'])
 
@@ -463,17 +489,25 @@ class AssetsCloner(object):
         ret = []
 
         dest_node = Node(root)
+        source_paths = self.node.trip_at(self.assets_path)
+        total_files_to_copy = len(source_paths)
 
-        for source_path in self.node.trip_at(self.assets_path):
+        for position, source_path in enumerate(source_paths, start=1):
             relative_path = self.node.relative(source_path)
 
             destination_path = dest_node.join(relative_path)
             destination_dir = dirname(destination_path)
 
             if not dest_node.contains(destination_dir):
+                before.folder_created.shout(destination_dir)
                 os.makedirs(destination_dir)
+                after.folder_created.shout(destination_dir)
 
+            before.file_copied.shout(
+                source_path, destination_path, position, total_files_to_copy)
             shutil.copy2(source_path, destination_path)
+            after.file_copied.shout(
+                source_path, destination_path, position, total_files_to_copy)
             ret.append(destination_path)
 
         return ret
